==> markdown-editor-1.0.1.tgz: package/es/Toolbar.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { forwardRef, useImperativeHandle, useRef, useState } from 'react';
import classnames from 'classnames';
import Icon from '@ant-design/icons';
import UndoOutlined from '@ant-design/icons/UndoOutlined';
import RedoOutlined from '@ant-design/icons/RedoOutlined';
import BoldOutlined from '@ant-design/icons/BoldOutlined';
import ItalicOutlined from '@ant-design/icons/ItalicOutlined';
import StrikethroughOutlined from '@ant-design/icons/StrikethroughOutlined';
import NumberOutlined from '@ant-design/icons/NumberOutlined';
import TableOutlined from '@ant-design/icons/TableOutlined';
import LineOutlined from '@ant-design/icons/LineOutlined';
import UnorderedListOutlined from '@ant-design/icons/UnorderedListOutlined';
import OrderedListOutlined from '@ant-design/icons/OrderedListOutlined';
import LinkOutlined from '@ant-design/icons/LinkOutlined';
import PictureOutlined from '@ant-design/icons/PictureOutlined';
import EyeOutlined from '@ant-design/icons/EyeOutlined';
import SplitCellsOutlined from '@ant-design/icons/SplitCellsOutlined';
import FullscreenOutlined from '@ant-design/icons/FullscreenOutlined';
import CodeSvg from './svg/code';
import QuoteSvg from './svg/quote';
import * as commands from './commands';
import "./Toolbar.css";
var isMac = navigator.userAgent.indexOf('Mac') > -1;

function fixKey(key) {
  return key.replace(/Mod/i, isMac ? 'Cmd' : 'Ctrl').toLowerCase().replace(/(-|^)[a-z]/g, function (s) {
    return s.toUpperCase();
  });
}

var Toolbar = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var buttons = _ref.buttons,
      onButtonClick = _ref.onButtonClick;

  var _extraCommandKeys = useRef({});

  var _useState = useState({}),
      _useState2 = _slicedToArray(_useState, 2),
      buttonState = _useState2[0],
      _setButtonState = _useState2[1];

  var _useState3 = useState(_extraCommandKeys.current),
      _useState4 = _slicedToArray(_useState3, 2),
      commandKeys = _useState4[0],
      setCommandKeys = _useState4[1];

  useImperativeHandle(ref, function () {
    return {
      setButtonState: function setButtonState(state) {
        if (Object.entries(state).some(function (_ref2) {
          var _ref3 = _slicedToArray(_ref2, 2),
              key = _ref3[0],
              value = _ref3[1];

          return value !== buttonState[key];
        })) {
          _setButtonState(_objectSpread(_objectSpread({}, buttonState), state));
        }
      },
      setKeymap: function setKeymap(keymap) {
        var commandKeys = Object.entries(commands).reduce(function (commandKeys, _ref4) {
          var _ref5 = _slicedToArray(_ref4, 2),
              type = _ref5[0],
              fn = _ref5[1];

          if (!commandKeys[type]) {
            var binding = keymap.find(function (binding) {
              return binding.run === fn || binding.shift === fn;
            });

            if ((binding === null || binding === void 0 ? void 0 : binding.run) === fn) {
              var _keymap$find;

              if (((_keymap$find = keymap.find(function (_ref6) {
                var key = _ref6.key;
                return key === binding.key;
              })) === null || _keymap$find === void 0 ? void 0 : _keymap$find.run) === (binding === null || binding === void 0 ? void 0 : binding.run)) {
                return Object.assign(commandKeys, _defineProperty({}, type, fixKey(binding.key)));
              }
            }

            if ((binding === null || binding === void 0 ? void 0 : binding.shift) === fn) {
              var _keymap$find2;

              if (((_keymap$find2 = keymap.find(function (_ref7) {
                var key = _ref7.key;
                return key === binding.key;
              })) === null || _keymap$find2 === void 0 ? void 0 : _keymap$find2.shift) === (binding === null || binding === void 0 ? void 0 : binding.shift)) {
                return Object.assign(commandKeys, _defineProperty({}, type, fixKey("Shift-".concat(binding.key))));
              }
            }
          }

          return commandKeys;
        }, _objectSpread({}, _extraCommandKeys.current));
        setCommandKeys(commandKeys);
      },
      extraCommandKeys: function extraCommandKeys(keys) {
        _extraCommandKeys.current = keys;
        setCommandKeys(_objectSpread(_objectSpread({}, commandKeys), keys));
      }
    };
  }, [buttonState]);

  var renderButtons = function renderButtons() {
    return buttons.map(function (button, index) {
      var _button$render;

      var type = typeof button === 'string' ? button : button.type;

      switch (type) {
        case '|':
          return /*#__PURE__*/React.createElement("span", {
            key: index,
            className: "pf-mde-divider"
          });

        case 'custom':
          return _typeof(button) === 'object' ? /*#__PURE__*/React.createElement("span", {
            key: index
          }, (_button$render = button.render) === null || _button$render === void 0 ? void 0 : _button$render.call(button)) : null;

        default:
          if (_typeof(button) === 'object' && button.render) {
            return /*#__PURE__*/React.createElement("span", {
              key: type,
              onClick: function onClick() {
                return onButtonClick === null || onButtonClick === void 0 ? void 0 : onButtonClick(type);
              }
            }, button.render());
          }

          return renderBuiltInButton(type);
      }
    });
  };

  var renderBuiltInButton = function renderBuiltInButton(type) {
    var _titleBinding$type;

    var iconBinding = {
      undo: /*#__PURE__*/React.createElement(UndoOutlined, null),
      redo: /*#__PURE__*/React.createElement(RedoOutlined, null),
      bold: /*#__PURE__*/React.createElement(BoldOutlined, null),
      italic: /*#__PURE__*/React.createElement(ItalicOutlined, null),
      strikethrough: /*#__PURE__*/React.createElement(StrikethroughOutlined, null),
      heading: /*#__PURE__*/React.createElement(NumberOutlined, null),
      quote: /*#__PURE__*/React.createElement(Icon, {
        component: QuoteSvg
      }),
      code: /*#__PURE__*/React.createElement(Icon, {
        component: CodeSvg
      }),
      table: /*#__PURE__*/React.createElement(TableOutlined, null),
      line: /*#__PURE__*/React.createElement(LineOutlined, null),
      unorderedList: /*#__PURE__*/React.createElement(UnorderedListOutlined, null),
      orderedList: /*#__PURE__*/React.createElement(OrderedListOutlined, null),
      link: /*#__PURE__*/React.createElement(LinkOutlined, null),
      image: /*#__PURE__*/React.createElement(PictureOutlined, null),
      preview: /*#__PURE__*/React.createElement(EyeOutlined, null),
      editorPreview: /*#__PURE__*/React.createElement(SplitCellsOutlined, null),
      fullScreen: /*#__PURE__*/React.createElement(FullscreenOutlined, null)
    };
    var titleBinding = {
      undo: '撤销',
      redo: '恢复',
      bold: '加粗',
      italic: '斜体',
      strikethrough: '删除线',
      heading: '标题',
      quote: '引用',
      code: '代码',
      table: '插入表格',
      line: '插入水平线',
      unorderedList: '无序列表',
      orderedList: '有序列表',
      link: '插入链接',
      image: '插入图片',
      preview: '预览',
      editorPreview: '编辑预览',
      fullScreen: '全屏'
    };
    return /*#__PURE__*/React.createElement("a", {
      key: type,
      className: classnames('pf-mde-button', {
        'pf-mde-button-active': buttonState[type]
      }),
      title: "".concat((_titleBinding$type = titleBinding[type]) !== null && _titleBinding$type !== void 0 ? _titleBinding$type : type).concat(commandKeys[type] || ''),
      onClick: function onClick() {
        return onButtonClick === null || onButtonClick === void 0 ? void 0 : onButtonClick(type);
      },
      children: iconBinding[type] || null
    });
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "pf-mde-toolbar"
  }, renderButtons());
});
export default Toolbar;

==> markdown-editor-1.0.2.tgz: package/es/Toolbar.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _iterableToArrayLimit(arr, i) { var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"]; if (_i == null) return; var _arr = []; var _n = true; var _d = false; var _s, _e; try { for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

import React, { forwardRef, useImperativeHandle, useRef, useState } from 'react';
import classnames from 'classnames';
import UndoSvg from './svg/undo';
import RedoSvg from './svg/redo';
import BoldSvg from './svg/bold';
import ItalicSvg from './svg/italic';
import StrikethroughSvg from './svg/strikethrough';
import NumberSvg from './svg/number';
import QuoteSvg from './svg/quote';
import CodeSvg from './svg/code';
import TableSvg from './svg/table';
import LineSvg from './svg/line';
import UnorderedListSvg from './svg/unordered-list';
import OrderedListSvg from './svg/ordered-list';
import LinkSvg from './svg/link';
import PictureSvg from './svg/picture';
import EyeSvg from './svg/eye';
import SplitCellsSvg from './svg/split-cells';
import FullscreenSvg from './svg/fullscreen';
import * as commands from './commands';
import "./Toolbar.css";
var isMac = navigator.userAgent.indexOf('Mac') > -1;

function fixKey(key) {
  return key.replace(/Mod/i, isMac ? 'Cmd' : 'Ctrl').toLowerCase().replace(/(-|^)[a-z]/g, function (s) {
    return s.toUpperCase();
  });
}

var Toolbar = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var buttons = _ref.buttons,
      onButtonClick = _ref.onButtonClick;

  var _extraCommandKeys = useRef({});

  var _useState = useState({}),
      _useState2 = _slicedToArray(_useState, 2),
      buttonState = _useState2[0],
      _setButtonState = _useState2[1];

  var _useState3 = useState(_extraCommandKeys.current),
      _useState4 = _slicedToArray(_useState3, 2),
      commandKeys = _useState4[0],
      setCommandKeys = _useState4[1];

  useImperativeHandle(ref, function () {
    return {
      setButtonState: function setButtonState(state) {
        if (Object.entries(state).some(function (_ref2) {
          var _ref3 = _slicedToArray(_ref2, 2),
              key = _ref3[0],
              value = _ref3[1];

          return value !== buttonState[key];
        })) {
          _setButtonState(_objectSpread(_objectSpread({}, buttonState), state));
        }
      },
      setKeymap: function setKeymap(keymap) {
        var commandKeys = Object.entries(commands).reduce(function (commandKeys, _ref4) {
          var _ref5 = _slicedToArray(_ref4, 2),
              type = _ref5[0],
              fn = _ref5[1];

          if (!commandKeys[type]) {
            var binding = keymap.find(function (binding) {
              return binding.run === fn || binding.shift === fn;
            });

            if ((binding === null || binding === void 0 ? void 0 : binding.run) === fn) {
              var _keymap$find;

              if (((_keymap$find = keymap.find(function (_ref6) {
                var key = _ref6.key;
                return key === binding.key;
              })) === null || _keymap$find === void 0 ? void 0 : _keymap$find.run) === (binding === null || binding === void 0 ? void 0 : binding.run)) {
                return Object.assign(commandKeys, _defineProperty({}, type, fixKey(binding.key)));
              }
            }

            if ((binding === null || binding === void 0 ? void 0 : binding.shift) === fn) {
              var _keymap$find2;

              if (((_keymap$find2 = keymap.find(function (_ref7) {
                var key = _ref7.key;
                return key === binding.key;
              })) === null || _keymap$find2 === void 0 ? void 0 : _keymap$find2.shift) === (binding === null || binding === void 0 ? void 0 : binding.shift)) {
                return Object.assign(commandKeys, _defineProperty({}, type, fixKey("Shift-".concat(binding.key))));
              }
            }
          }

          return commandKeys;
        }, _objectSpread({}, _extraCommandKeys.current));
        setCommandKeys(commandKeys);
      },
      extraCommandKeys: function extraCommandKeys(keys) {
        _extraCommandKeys.current = keys;
        setCommandKeys(_objectSpread(_objectSpread({}, commandKeys), keys));
      }
    };
  }, [buttonState]);

  var renderButtons = function renderButtons() {
    return buttons.map(function (button, index) {
      var _button$render;

      var type = typeof button === 'string' ? button : button.type;

      switch (type) {
        case '|':
          return /*#__PURE__*/React.createElement("span", {
            key: index,
            className: "pf-mde-divider"
          });

        case 'custom':
          return _typeof(button) === 'object' ? /*#__PURE__*/React.createElement("span", {
            key: index
          }, (_button$render = button.render) === null || _button$render === void 0 ? void 0 : _button$render.call(button)) : null;

        default:
          if (_typeof(button) === 'object' && button.render) {
            return /*#__PURE__*/React.createElement("span", {
              key: type,
              onClick: function onClick() {
                return onButtonClick === null || onButtonClick === void 0 ? void 0 : onButtonClick(type);
              }
            }, button.render());
          }

          return renderBuiltInButton(type);
      }
    });
  };

  var renderBuiltInButton = function renderBuiltInButton(type) {
    var _titleBinding$type;

    var svgProps = {
      viewBox: '64 64 896 896',
      width: '1em',
      height: '1em',
      fill: 'currentcolor',
      focusable: 'false'
    };
    var iconBinding = {
      undo: /*#__PURE__*/React.createElement(UndoSvg, _objectSpread({
        "data-icon": "bold"
      }, svgProps)),
      redo: /*#__PURE__*/React.createElement(RedoSvg, _objectSpread({
        "data-icon": "redo"
      }, svgProps)),
      bold: /*#__PURE__*/React.createElement(BoldSvg, _objectSpread({
        "data-icon": "bold"
      }, svgProps)),
      italic: /*#__PURE__*/React.createElement(ItalicSvg, _objectSpread({
        "data-icon": "italic"
      }, svgProps)),
      strikethrough: /*#__PURE__*/React.createElement(StrikethroughSvg, _objectSpread({
        "data-icon": "strikethrough"
      }, svgProps)),
      heading: /*#__PURE__*/React.createElement(NumberSvg, _objectSpread({
        "data-icon": "heading"
      }, svgProps)),
      quote: /*#__PURE__*/React.createElement(QuoteSvg, _objectSpread({
        "data-icon": "quote"
      }, svgProps)),
      code: /*#__PURE__*/React.createElement(CodeSvg, _objectSpread({
        "data-icon": "code"
      }, svgProps)),
      table: /*#__PURE__*/React.createElement(TableSvg, _objectSpread({
        "data-icon": "table"
      }, svgProps)),
      line: /*#__PURE__*/React.createElement(LineSvg, _objectSpread({
        "data-icon": "line"
      }, svgProps)),
      unorderedList: /*#__PURE__*/React.createElement(UnorderedListSvg, _objectSpread({
        "data-icon": "unordered-list"
      }, svgProps)),
      orderedList: /*#__PURE__*/React.createElement(OrderedListSvg, _objectSpread({
        "data-icon": "ordered-list"
      }, svgProps)),
      link: /*#__PURE__*/React.createElement(LinkSvg, _objectSpread({
        "data-icon": "link"
      }, svgProps)),
      image: /*#__PURE__*/React.createElement(PictureSvg, _objectSpread({
        "data-icon": "image"
      }, svgProps)),
      preview: /*#__PURE__*/React.createElement(EyeSvg, _objectSpread({
        "data-icon": "preview"
      }, svgProps)),
      editorPreview: /*#__PURE__*/React.createElement(SplitCellsSvg, _objectSpread({
        "data-icon": "editor-preview"
      }, svgProps)),
      fullScreen: /*#__PURE__*/React.createElement(FullscreenSvg, _objectSpread({
        "data-icon": "fullScreen"
      }, svgProps))
    };
    var titleBinding = {
      undo: '撤销',
      redo: '恢复',
      bold: '加粗',
      italic: '斜体',
      strikethrough: '删除线',
      heading: '标题',
      quote: '引用',
      code: '代码',
      table: '插入表格',
      line: '插入水平线',
      unorderedList: '无序列表',
      orderedList: '有序列表',
      link: '插入链接',
      image: '插入图片',
      preview: '预览',
      editorPreview: '编辑预览',
      fullScreen: '全屏'
    };
    return /*#__PURE__*/React.createElement("a", {
      key: type,
      className: classnames('pf-mde-button', {
        'pf-mde-button-active': buttonState[type]
      }),
      title: "".concat((_titleBinding$type = titleBinding[type]) !== null && _titleBinding$type !== void 0 ? _titleBinding$type : type).concat(commandKeys[type] || ''),
      onClick: function onClick() {
        return onButtonClick === null || onButtonClick === void 0 ? void 0 : onButtonClick(type);
      },
      children: iconBinding[type] || null
    });
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "pf-mde-toolbar"
  }, renderButtons());
});
export default Toolbar;
